@@ -29,8 +29,9 @@
 #include "dialog_installer.h"
 #include "dialog_uninstaller.h"
 #include <kns3/downloaddialog.h>
+#include "iconthemesmodel.h"
+#include "cursorthemesmodel.h"
 
-class IconThemesModel;
 class KProcess;
 class QX11EmbedContainer;
 namespace Ui { class Modulo; class GUI; }
@@ -44,9 +45,9 @@ public:
     
     void refreshThemesUi(bool useConfig=false);
     
-    virtual void save();
-    virtual void defaults();
-    virtual void load();
+    void save() override;
+    void defaults() override;
+    void load() override;
     
 public slots:
     void refreshLists();
@@ -71,6 +72,7 @@ signals:
     
 private:
     void syncUI();
+    bool m_loading = false;
     
     Ui::GUI *ui;
     AppearenceGTK *appareance;
@@ -82,6 +84,7 @@ private:
     QString m_tempGtk2Preview;
     QString m_tempGtk3Preview;
     bool m_saveEnabled;
+    CursorThemesModel* m_cursorsModel;
     IconThemesModel* m_iconsModel;
 };
 
